//--------------------------------------------------------------------
//     此代码由T4模板自动生成  byzhouhang 20210918
//	   生成时间 2022-01-05 09:17:00 
//     对此文件的更改可能会导致不正确的行为，并且如果重新生成代码，这些更改将会丢失。
//--------------------------------------------------------------------
namespace IRaCIS.Core.Application.Contracts
{
    /// <summary>
    /// ISystemDocumentService
    /// </summary>	
    public interface ISystemDocumentService
    {

        //PageOutput<SystemDocumentView> GetSystemDocumentList(SystemDocumentQuery querySystemDocument);


        //IResponseOutput AddOrUpdateSystemDocument(AddOrEditSystemDocument addOrEditSystemDocument);

        //IResponseOutput DeleteSystemDocument(Guid systemDocumentId);

        Task<PageOutput<SystemDocumentView>> GetSystemDocumentListAsync(SystemDocumentQuery querySystemDocument);

        Task<IResponseOutput> AddOrUpdateSystemDocumentAsync(AddOrEditSystemDocument addOrEditSystemDocument);

        Task<IResponseOutput> DeleteSystemDocumentAsync(Guid systemDocumentId);

        Task<PageOutput<UnionDocumentWithConfirmInfoView>> getWaitSignSysDocList(SystemDocumentQuery querySystemDocument);


        Task<PageOutput<SystemDocumentAttachmentView>> GetSystemDocumentAttachmentList(SystemDocumentAttachmentQuery inQuery);

        Task<IResponseOutput> AddOrUpdateSystemDocumentAttachment(SystemDocumentAttachmentAddOrEdit addOrEditSystemDocumentAttachment);

        Task<IResponseOutput> DeleteSystemDocumentAttachment(Guid systemDocumentAttachmentId);




    }
}
